# Table of Contents

- [increasing-your-data-quality](<./increasing-your-data-quality.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Increasing Your Data Quality](<./Increasing-Your-Data-Quality.md>)
  - [Introduction](<./Increasing-Your-Data-Quality/Introduction.md>)
  - [Fact Sheet Completion Score](<./Increasing-Your-Data-Quality/Fact-Sheet-Completion-Score.md>)
  - [Fact Sheet Subscription](<./Increasing-Your-Data-Quality/Fact-Sheet-Subscription.md>)
  - [Quality Seal](<./Increasing-Your-Data-Quality/Quality-Seal.md>)
  - [Mandatory Attributes](<./Increasing-Your-Data-Quality/Mandatory-Attributes.md>)
  - [Data Quality Insights](<./Increasing-Your-Data-Quality/Data-Quality-Insights.md>)
  - [Surveys](<./Increasing-Your-Data-Quality/Surveys.md>)
  - [Reference Catalog](<./Increasing-Your-Data-Quality/Reference-Catalog.md>)
  - [Discoveries and Integrations](<./Increasing-Your-Data-Quality/Discoveries-and-Integrations.md>)
